function [predictionArray, errorArray, MSE, RMSE] = ARIMA_App(inputTimeSeries, forecast_t_start, forecast_t_end, params, diffOrder, verbose)

T = length(inputTimeSeries);

predictionArray = [];
errorArray = [];

sum_se = 0;

if(diffOrder == 0)
    for t=forecast_t_start:forecast_t_end
        [estimation, error] = ARIMA(inputTimeSeries, t, params);
    end
else
    dimension = max(T, forecast_t_end);
    diffTimeSeries_matrix = zeros(diffOrder, dimension);
        
    diffTimeSeries = inputTimeSeries;
    for i=1:diffOrder
        diffTimeSeries = differencing(diffTimeSeries);
        for j=1+diffOrder:T
            diffTimeSeries_matrix(i,j) = diffTimeSeries(j-diffOrder);
        end
    end
    
    inputTimeSeries_tmp = zeros(1, dimension);
    for t=1:T
        inputTimeSeries_tmp(t) = inputTimeSeries(t);
    end

    diffTimeSeries_matrix = [inputTimeSeries_tmp; diffTimeSeries_matrix];
    
    for t=forecast_t_start:forecast_t_end
        if(t<=diffOrder)
            estimation = inputTimeSeries(t);
        else
            [estimation_tmp, error_tmp] = ARIMA(diffTimeSeries, t - diffOrder, params);
            
            estimation = estimation_tmp;
            t_tmp = t - diffOrder;
            if(t>T)
                for i=diffOrder-1:-1:0
                    diffTimeSeries = diffTimeSeries_matrix(i+1,:);
                    estimation = diffTimeSeries(t_tmp) + estimation;
                    diffTimeSeries(1, t_tmp+1) = estimation;

                    t_tmp = t_tmp + 1;
                end
            else
                for i=diffOrder-1:-1:0
                    diffTimeSeries = diffTimeSeries_matrix(i+1,:);
                    estimation = diffTimeSeries(t_tmp) + estimation;
                    t_tmp = t_tmp + 1;
                end
            end

        end
    
        if(t<=T)
            error = inputTimeSeries(t) - estimation;
        else
            error = 0;
        end

        sum_se = sum_se + error*error; 

        predictionArray = [predictionArray, estimation];
        errorArray = [errorArray, error];
        
        if(verbose ==1)
            disp(['-------------fitting for time index', num2str(t), '------------']);
        end
    end
end

MSE = sum_se/length(errorArray);
RMSE = sqrt(MSE);

end
